===============================
ANDES: ANother Dynamic Energy System simulator
===============================

.. image:: https://img.shields.io/travis/cuihantao/andes.svg
        :target: https://travis-ci.org/cuihantao/andes

.. image:: https://img.shields.io/pypi/v/andes.svg
        :target: https://pypi.python.org/pypi/andes

.. image:: https://api.codacy.com/project/badge/Grade/17b8e8531af343a7a4351879c0e6b5da
   :alt: Codacy Badge
   :target: https://app.codacy.com/app/cuihantao/andes?utm_source=github.com&utm_medium=referral&utm_content=cuihantao/andes&utm_campaign=Badge_Grade_Dashboard

A Python package for power system research

* Open-source software: Apache License, see LICENSE.md
* Documentation: https://andes.readthedocs.io

Features
--------

ANDES is a Python-based power system simulation tool for research. It
supports power flow calculation, time domain simulation, and full eigenvalue
analysis for transmission networks. ANDES is currently under active development.


Acknowledgement
---------------
This work was supported in part by the Engineering Research Center Program of
the National Science Foundation and the Department of Energy under NSF Award
Number EEC-1041877 and the CURENT Industry Partnership Program.
